==> create-typescript-app-2.15.2.tgz: package/lib/blocks/blockKnip.js <==
import { z } from "zod";
import { base } from "../base.js";
import {
  getPackageDependencies,
  getPackageDependency
} from "../data/packageData.js";
import { blockDevelopmentDocs } from "./blockDevelopmentDocs.js";
import { blockGitHubActionsCI } from "./blockGitHubActionsCI.js";
import { blockPackageJson } from "./blockPackageJson.js";
import { blockRemoveFiles } from "./blockRemoveFiles.js";
import { blockRemoveWorkflows } from "./blockRemoveWorkflows.js";
const blockKnip = base.createBlock({
  about: {
    name: "Knip"
  },
  addons: {
    ignoreDependencies: z.array(z.string()).optional()
  },
  produce({ addons }) {
    const { ignoreDependencies } = addons;
    return {
      addons: [
        blockDevelopmentDocs({
          sections: {
            Linting: {
              contents: {
                items: [
                  `- \`pnpm lint:knip\` ([knip](https://github.com/webpro/knip)): Detects unused files, dependencies, and code exports`
                ]
              }
            }
          }
        }),
        blockGitHubActionsCI({
          jobs: [
            {
              name: "Lint Knip",
              steps: [{ run: "pnpm lint:knip" }]
            }
          ]
        }),
        blockPackageJson({
          properties: {
            devDependencies: getPackageDependencies("knip"),
            scripts: {
              "lint:knip": "knip"
            }
          }
        })
      ],
      files: {
        "knip.json": JSON.stringify({
          $schema: `https://unpkg.com/knip@${getPackageDependency("knip")}/schema.json`,
          entry: ["src/index.ts", "src/**/*.test.*"],
          ignoreDependencies,
          ignoreExportsUsedInFile: {
            interface: true,
            type: true
          },
          project: ["src/**/*.ts"]
        })
      }
    };
  },
  transition() {
    return {
      addons: [
        blockRemoveFiles({
          files: [".knip*", "knip.{c,m,t}*", "knip.js", "knip.jsonc"]
        }),
        blockRemoveWorkflows({
          workflows: ["knip", "lint-knip"]
        })
      ]
    };
  }
});
export {
  blockKnip
};

==> create-typescript-app-2.22.1.tgz: package/lib/blocks/blockKnip.js <==
import { z } from "zod";
import { base } from "../base.js";
import {
  getPackageDependencies,
  getPackageDependency
} from "../data/packageData.js";
import { blockDevelopmentDocs } from "./blockDevelopmentDocs.js";
import { blockGitHubActionsCI } from "./blockGitHubActionsCI.js";
import { blockPackageJson } from "./blockPackageJson.js";
import { blockRemoveFiles } from "./blockRemoveFiles.js";
import { blockRemoveWorkflows } from "./blockRemoveWorkflows.js";
import { intakeFileAsJson } from "./intake/intakeFileAsJson.js";
const zIgnoreDependencies = z.array(z.string());
const blockKnip = base.createBlock({
  about: {
    name: "Knip"
  },
  addons: {
    ignoreDependencies: zIgnoreDependencies.optional()
  },
  intake({ files }) {
    const knipJson = intakeFileAsJson(files, ["knip.json"]);
    if (!knipJson?.ignoreDependencies) {
      return void 0;
    }
    return {
      ignoreDependencies: zIgnoreDependencies.safeParse(
        knipJson.ignoreDependencies
      ).data
    };
  },
  produce({ addons }) {
    const { ignoreDependencies } = addons;
    return {
      addons: [
        blockDevelopmentDocs({
          sections: {
            Linting: {
              contents: {
                items: [
                  `- \`pnpm lint:knip\` ([knip](https://github.com/webpro/knip)): Detects unused files, dependencies, and code exports`
                ]
              }
            }
          }
        }),
        blockGitHubActionsCI({
          jobs: [
            {
              name: "Lint Knip",
              steps: [{ run: "pnpm lint:knip" }]
            }
          ]
        }),
        blockPackageJson({
          properties: {
            devDependencies: getPackageDependencies("knip"),
            scripts: {
              "lint:knip": "knip"
            }
          }
        })
      ],
      files: {
        "knip.json": JSON.stringify({
          $schema: `https://unpkg.com/knip@${getPackageDependency("knip")}/schema.json`,
          entry: ["src/index.ts", "src/**/*.test.*"],
          ignoreDependencies,
          ignoreExportsUsedInFile: {
            interface: true,
            type: true
          },
          project: ["src/**/*.ts"]
        })
      }
    };
  },
  transition() {
    return {
      addons: [
        blockRemoveFiles({
          files: [".knip*", "knip.{c,m,t}*", "knip.js", "knip.jsonc"]
        }),
        blockRemoveWorkflows({
          workflows: ["knip", "lint-knip"]
        })
      ]
    };
  }
});
export {
  blockKnip
};
